@@ -7,8 +7,8 @@ typedef void MethodAttributeHandler(pTHX_ MethodMeta *meta, const char *value, v
 struct MethodMeta {
   SV *name;
   ClassMeta *class;
-  /* We don't store the method body CV; leave that in the class stash */
-  unsigned int is_common : 1;
+  int8_t is_common;
+  int8_t is_required;
 };
 
 struct MethodAttributeDefinition {
