@@ -5,6 +5,8 @@ use warnings;
 
 sub class {}
 
+sub role {}
+
 sub field {}
 
 sub method {}
@@ -17,6 +19,8 @@ sub common {}
 
 class(1);
 
+role(1);
+
 field(1);
 
 method(3);
